summaryrefslogtreecommitdiff
path: root/nuttx/configs/pcduino-a10
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-01-24 13:50:23 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-01-24 13:50:23 -0600
commitea439de0bb25f37ffc4004b6532bf53810511c3d (patch)
tree577b3e0aaa6a2878a6cc5d91792383781879fc28 /nuttx/configs/pcduino-a10
parent1e646824d1fee99cba2f721cfc2181cfdd31d7f1 (diff)
downloadpx4-nuttx-ea439de0bb25f37ffc4004b6532bf53810511c3d.tar.gz
px4-nuttx-ea439de0bb25f37ffc4004b6532bf53810511c3d.tar.bz2
px4-nuttx-ea439de0bb25f37ffc4004b6532bf53810511c3d.zip
Rename up_buttoninit to board_button_intialize
Diffstat (limited to 'nuttx/configs/pcduino-a10')
-rw-r--r--nuttx/configs/pcduino-a10/include/board.h42
-rw-r--r--nuttx/configs/pcduino-a10/src/a1x_buttons.c11
2 files changed, 6 insertions, 47 deletions
diff --git a/nuttx/configs/pcduino-a10/include/board.h b/nuttx/configs/pcduino-a10/include/board.h
index b5b0f3b71..09f5820a7 100644
--- a/nuttx/configs/pcduino-a10/include/board.h
+++ b/nuttx/configs/pcduino-a10/include/board.h
@@ -201,48 +201,6 @@ void a1x_setled(int led, bool ledon);
void a1x_setleds(uint8_t ledset);
#endif
-/************************************************************************************
- * Name: up_buttoninit
- *
- * Description:
- * up_buttoninit() must be called to initialize button resources. After that,
- * up_buttons() may be called to collect the current state of all buttons or
- * up_irqbutton() may be called to register button interrupt handlers.
- *
- ************************************************************************************/
-
-#ifdef CONFIG_ARCH_BUTTONS
-void up_buttoninit(void);
-
-/************************************************************************************
- * Name: up_buttons
- *
- * Description:
- * After up_buttoninit() has been called, up_buttons() may be called to collect
- * the state of all buttons. up_buttons() returns an 8-bit bit set with each bit
- * associated with a button. See the BUTTON* definitions above for the meaning of
- * each bit in the returned value.
- *
- ************************************************************************************/
-
-uint8_t up_buttons(void);
-
-/************************************************************************************
- * Name: up_irqbutton
- *
- * Description:
- * This function may be called to register an interrupt handler that will be
- * called when a button is depressed or released. The ID value is one of the
- * BUTTON* definitions provided above. The previous interrupt handler address is
- * returned (so that it may restored, if so desired).
- *
- ************************************************************************************/
-
-#ifdef CONFIG_A1X_PIO_IRQ
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler);
-#endif
-#endif /* CONFIG_ARCH_BUTTONS */
-
#undef EXTERN
#if defined(__cplusplus)
}
diff --git a/nuttx/configs/pcduino-a10/src/a1x_buttons.c b/nuttx/configs/pcduino-a10/src/a1x_buttons.c
index 234756854..f537e4060 100644
--- a/nuttx/configs/pcduino-a10/src/a1x_buttons.c
+++ b/nuttx/configs/pcduino-a10/src/a1x_buttons.c
@@ -1,7 +1,7 @@
/****************************************************************************
* configs/pcduino-a10/src/a1x_buttons.c
*
- * Copyright (C) 2013 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2013-2014 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
*
* Redistribution and use in source and binary forms, with or without
@@ -41,6 +41,7 @@
#include <stdint.h>
+#include <nuttx/arch.h>
#include <nuttx/irq.h>
#include <arch/irq.h>
@@ -71,17 +72,17 @@ static xcpt_t g_irqbutton[BOARD_NBUTTONS];
****************************************************************************/
/****************************************************************************
- * Name: up_buttoninit
+ * Name: board_button_initialize
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
-void up_buttoninit(void)
+void board_button_initialize(void)
{
# warning Missing logic
}
@@ -90,7 +91,7 @@ void up_buttoninit(void)
* Name: up_buttons
*
* Description:
* After up_buttoninit() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON* definitions
* above for the meaning of each bit in the returned value.
@@ -71,17 +72,17 @@ static xcpt_t g_irqbutton[BOARD_NBUTTONS];
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -90,7 +91,7 @@ void up_buttoninit(void)
*
* Description:
- * After up_buttoninit() has been called, up_buttons() may be called to
+ * After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON* definitions